@@ -10,9 +10,9 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.9.6"
+#define MARIADB_CLIENT_VERSION_STR	"10.9.8"
 #define MARIADB_BASE_VERSION		"mariadb-10.9"
-#define MARIADB_VERSION_ID		100906
+#define MARIADB_VERSION_ID		100908
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/var/run/mysql/mysql.sock"
 #ifndef MYSQL_UNIX_ADDR
@@ -23,13 +23,13 @@
 #endif
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100906
-#define MYSQL_SERVER_VERSION            "10.9.6-MariaDB"
+#define MYSQL_VERSION_ID                100908
+#define MYSQL_SERVER_VERSION            "10.9.8-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.3.5"
-#define MARIADB_PACKAGE_VERSION_ID 30305
+#define MARIADB_PACKAGE_VERSION "3.3.6"
+#define MARIADB_PACKAGE_VERSION_ID 30306
 #define MARIADB_SYSTEM_TYPE "OpenBSD"
-#define MARIADB_MACHINE_TYPE "aarch64"
+#define MARIADB_MACHINE_TYPE "powerpc"
 #define MARIADB_PLUGINDIR "/usr/local/lib/mysql/plugin"
 
 /* mysqld compile time options */
